--[[

Define English-language strings and chat message parsing funtion

]]--

_G.L = {};

L["PluginLoaded"] = " by K1R4D3L loaded";
L["PluginUnloaded"] = " by K1R4D3L unloaded";

L["CmdShow"] = "show";
L["CmdShowDesc"] = "Displays the KillTracker main window";
L["Usage"] = "usage";

L["LoadFailure"] = "Unable to load data file. Data will not save until data file is repaired or deleted and plugin is reloaded.";

L["NoRows"] = "No data to display."

L["ShowAllCharacters"] = "Show All Characters";

L["NumberSplitChar"] = ",";

L["DirectDamage"] = "Direct Damage";
L["TrapDamage"] = "Trap Damage";
L["TheTrap"] = "The Trap";

L["MobName"] = "Enemy Name";
L["CharacterName"] = "Character";
L["LevelRange"] = "Levels";
L["KillCount"] = "Kills";

function L.Parse(line, channel)
  	-- find damage-dealing hits to mobs by character's pets, soldiers and devices
   if (channel == Turbine.ChatType.PlayerCombat) then
      -- only include hits to Morale
      local initiatorName, skillName, targetNameAndAmount = string.match(line, "^(.*) scored a .*hit(.*) on (.*)damage to Morale%.$");
	
      if (initiatorName ~= nil) then
         skillName = string.match(skillName, "^ with (.*)$") or L.DirectDamage;

         -- need to handle devices specially because kill messages don't match hit messages
         if (skillName == L.TrapDamage) then
            initiatorName = L.TheTrap;
         else
            initiatorName = string.gsub(initiatorName, "^[Tt]he ","");
         end

         -- skip character hits - don't need to use hit-matching for kills by the player directly
         --    if a player names a pet/soldier the same name as their character, this would miss (don't do that)
         if (initiatorName ~= player.name) then
            local targetName, amount = string.match(targetNameAndAmount, "^(.*) for ([%d,]*) .*$");

            if (targetName ~= nil) then
			      targetName = string.gsub(targetName, "^[Tt]he ","");

			      amount = string.gsub(amount, ",", "") + 0;

               -- only include damage-dealing hits
               if (amount > 0) then
                  return 1, initiatorName, targetName;
               end
            end
         end
      end
   -- find damage-dealing reflects to mobs by character's pets and soldiers
   elseif (channel == Turbine.ChatType.EnemyCombat) then
      -- only include reflects to Morale
      local initiatorName, amount, dmgType, targetName = string.match(line, "^(.*) reflected ([%d,]*) (.*)damage to the Morale of (.*)%.$");
	
      if ((initiatorName ~= nil) and (dmgType ~= nil)) then
         -- skip character reflects - don't need to use hit-matching for kills by the player directly
         --    if a player names a pet/soldier the same name as their character, this would miss (don't do that)
         if (initiatorName ~= player.name) then
            initiatorName = string.gsub(initiatorName, "^[Tt]he ","");

            targetName = string.gsub(targetName, "^[Tt]he ","");

            amount = string.gsub(amount, ",", "") + 0;

            if (amount > 0) then
               return 1, initiatorName, targetName;
            end
         end
      end
   -- find mob kills by character and their pets, soldiers and devices
   elseif (channel == Turbine.ChatType.Death) then
      -- mob kills by the character directly
      local targetName = string.match(line, "^Your mighty blow defeated (.*)%.$");

      if (targetName ~= nil) then
         targetName = string.gsub(targetName,"^[Tt]he ","");

         -- indicates that hit-matching and in-combat checking is not necessary
         local initiatorName = "$PLAYER$";
	
         return 9, initiatorName, targetName;
      end

      -- mob kills by the character directly (format 2)
      local targetName = string.match(line, "^Your mighty blow topples (.*)%.$");

      if (targetName ~= nil) then
         targetName = string.gsub(targetName,"^[Tt]he ","");

         -- indicates that hit-matching and in-combat checking is not necessary
         local initiatorName = "$PLAYER$";
	
         return 9, initiatorName, targetName;
      end

      -- mob kills not by the character directly
      local initiatorName, targetName = string.match(line, "^(.*) defeated (.*)%.$");

      if (initiatorName ~= nil) then
         -- keeping "The" on special devices to differentiate them
         if (initiatorName ~= "The Trap") then
            initiatorName = string.gsub(initiatorName, "^[Tt]he ", "");
         end

         targetName = string.gsub(targetName, "^[Tt]he ","");
	
         return 9, initiatorName, targetName;
      end
   end
end

